@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pyimpsort" "0.1.1"
+(define-package "pyimpsort" "20250710.1607"
   "Sort Python imports."
   '((emacs  "24.3")
     (python "0"))
